@@ -1,7 +1,7 @@
 package App::FilterOrgByHeadlines;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2015-12-25'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010;
 use strict;
@@ -104,6 +104,18 @@ _
                 'Only include headline which is a todo item but not done',
             tags => ['category:filtering'],
         },
+        has_tags => {
+            'x.name.is_plural' => 1,
+            schema => ['array*', of=>'str*'],
+            summary => 'Only include headline which have all these tags',
+            tags => ['category:filtering'],
+        },
+        lacks_tags => {
+            'x.name.is_plural' => 1,
+            schema => ['array*', of=>'str*'],
+            summary => 'Only include headline which lack all these tags',
+            tags => ['category:filtering'],
+        },
 
         # XXX todo_state => str*
         with_content => {
@@ -144,6 +156,7 @@ sub filter_org_by_headlines {
     my $curlevel;
     my $curtodokw;
     my $curhl_filtered;
+    my $curtags;
     my @parenthls; # ([hl, level], ...)
 
     my %todo_keywords = map {$_=>1} qw(TODO);
@@ -170,6 +183,12 @@ sub filter_org_by_headlines {
             my $level = length($1);
             my $arg = $2;
 
+            if ($line =~ /\s+:(\w+(?::\w+)*):(?:\s+|$)/) {
+                $curtags = [split /:/, $1];
+            } else {
+                undef $curtags;
+            }
+
             if ($curlevel && $curlevel < $level) {
                 push @parenthls, [$curhl, $curlevel];
             } elsif (@parenthls) {
@@ -224,6 +243,17 @@ sub filter_org_by_headlines {
             if (defined $args{match}) {
                 last unless _match($curhl, $args{match});
             }
+            if ($args{has_tags}) {
+                last unless $curtags;
+                for my $t (@{ $args{has_tags} }) {
+                    last FILTER unless grep {$t eq $_} @$curtags;
+                }
+            }
+            if ($args{lacks_tags}) {
+                for my $t (@{ $args{lacks_tags} }) {
+                    last FILTER if grep {$t eq $_} @{$curtags//[]};
+                }
+            }
             if (defined $args{parent_match}) {
                 last unless @parenthls;
                 last unless _match($parenthls[-1][0], $args{parent_match});
@@ -271,7 +301,7 @@ App::FilterOrgByHeadlines - Filter Org by headlines
 
 =head1 VERSION
 
-This document describes version 0.33 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-09-03.
+This document describes version 0.34 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-12-25.
 
 =head1 FUNCTIONS
 
@@ -282,6 +312,8 @@ Filter Org by headlines.
 
 This routine uses simple regex instead of Org::Parser, for faster performance.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -293,6 +325,10 @@ Only include headline whose ascendant matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<has_tags> => I<array[str]>
+
+Only include headline which have all these tags.
+
 =item * B<input>* => I<str>
 
 Value is either a string or an array of strings.
@@ -305,6 +341,10 @@ Only include headline which is a done todo item.
 
 Only include headline which is a todo item.
 
+=item * B<lacks_tags> => I<array[str]>
+
+Only include headline which lack all these tags.
+
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
