@@ -1,7 +1,7 @@
 package App::ListOrgHeadlinesFast;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2015-12-25'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010;
 use strict;
@@ -29,12 +29,15 @@ $SPEC{list_org_headlines} = do {
 sub list_org_headlines {
     my %args = @_;
 
-    App::FilterOrgByHeadlines::filter_org_by_headlines(
+    my $headlines = App::FilterOrgByHeadlines::filter_org_by_headlines(
         %args,
         with_content => 0,
         with_preamble => 0,
         return_array => 1,
     );
+
+    chomp for @$headlines;
+    $headlines;
 }
 
 $SPEC{list_org_todos} = do {
@@ -96,7 +99,7 @@ App::ListOrgHeadlinesFast - List & count Org headlines & todos
 
 =head1 VERSION
 
-This document describes version 0.33 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-09-03.
+This document describes version 0.34 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-12-25.
 
 =head1 FUNCTIONS
 
@@ -107,6 +110,8 @@ Count Org headlines.
 
 This routine uses simple regex instead of Org::Parser, for faster performance.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -118,6 +123,10 @@ Only include headline whose ascendant matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<has_tags> => I<array[str]>
+
+Only include headline which have all these tags.
+
 =item * B<input>* => I<str>
 
 Value is either a string or an array of strings.
@@ -130,6 +139,10 @@ Only include headline which is a done todo item.
 
 Only include headline which is a todo item.
 
+=item * B<lacks_tags> => I<array[str]>
+
+Only include headline which lack all these tags.
+
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
@@ -161,6 +174,8 @@ Count Org todos.
 
 This routine uses simple regex instead of Org::Parser, for faster performance.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -172,6 +187,10 @@ Only include headline whose ascendant matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<has_tags> => I<array[str]>
+
+Only include headline which have all these tags.
+
 =item * B<input>* => I<str>
 
 Value is either a string or an array of strings.
@@ -180,6 +199,10 @@ Value is either a string or an array of strings.
 
 Only include headline which is a done todo item.
 
+=item * B<lacks_tags> => I<array[str]>
+
+Only include headline which lack all these tags.
+
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
@@ -211,6 +234,8 @@ List Org headlines.
 
 This routine uses simple regex instead of Org::Parser, for faster performance.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -222,6 +247,10 @@ Only include headline whose ascendant matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<has_tags> => I<array[str]>
+
+Only include headline which have all these tags.
+
 =item * B<input>* => I<str>
 
 Value is either a string or an array of strings.
@@ -234,6 +263,10 @@ Only include headline which is a done todo item.
 
 Only include headline which is a todo item.
 
+=item * B<lacks_tags> => I<array[str]>
+
+Only include headline which lack all these tags.
+
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
@@ -265,6 +298,8 @@ List Org todos.
 
 This routine uses simple regex instead of Org::Parser, for faster performance.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -276,6 +311,10 @@ Only include headline whose ascendant matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<has_tags> => I<array[str]>
+
+Only include headline which have all these tags.
+
 =item * B<input>* => I<str>
 
 Value is either a string or an array of strings.
@@ -284,6 +323,10 @@ Value is either a string or an array of strings.
 
 Only include headline which is a done todo item.
 
+=item * B<lacks_tags> => I<array[str]>
+
+Only include headline which lack all these tags.
+
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
